@@ -1,5 +1,5 @@
 /*
- * SPDX-FileCopyrightText: 2010 Klaralvdalens Datakonsult AB a KDAB Group company, info@kdab.com
+ * SPDX-FileCopyrightText: 2010 Klaralvdalens Datakonsult AB a KDAB Group company, <info@kdab.com>
  * SPDX-FileCopyrightText: 2010 Leo Franchi <lfranchi@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
@@ -10,11 +10,13 @@
 
 #include "akonadi-mime_export.h"
 
-namespace KMime {
+namespace KMime
+{
 class Message;
 }
 
-namespace Akonadi {
+namespace Akonadi
+{
 class Item;
 
 /**
@@ -23,7 +25,8 @@ class Item;
  * This namespace contains identifiers of message flags that
  *  are used internally in the Akonadi server.
  */
-namespace MessageFlags {
+namespace MessageFlags
+{
 /**
  * The flag for a message being seen (i.e. opened by user).
  */
